@@ -34,6 +34,7 @@ static ServiceRole services[] = {
 	{ "acct",                   GST_ROLE_SYSTEM_MONITORING },
 	{ "acpid",                  GST_ROLE_POWER_MANAGEMENT },
 	{ "alsa",                   GST_ROLE_AUDIO_MANAGEMENT },
+	{ "alsasound",              GST_ROLE_AUDIO_MANAGEMENT },
 	{ "alsa-utils",             GST_ROLE_AUDIO_MANAGEMENT },
 	{ "am-utils",               GST_ROLE_AUTOMOUNTER },
 	{ "amavis",                 GST_ROLE_ANTIVIRUS },
@@ -51,6 +52,7 @@ static ServiceRole services[] = {
 	{ "aumix",                  GST_ROLE_AUDIO_MANAGEMENT },
 	{ "autofs",                 GST_ROLE_AUTOMOUNTER },
 	{ "avahi-daemon",           GST_ROLE_RENDEZVOUS },
+	{ "avahi-dnsconfd",         GST_ROLE_RENDEZVOUS },
 	{ "backuppc",               GST_ROLE_REMOTE_BACKUP },
 	{ "bind",                   GST_ROLE_DNS },
 	{ "bind9",                  GST_ROLE_DNS },
@@ -60,6 +62,8 @@ static ServiceRole services[] = {
 	{ "capiutils",              GST_ROLE_ISDN_MANAGEMENT },
 	{ "cherokee",               GST_ROLE_WEB_SERVER },
 	{ "clamav-daemon",          GST_ROLE_ANTIVIRUS },
+	{ "clamav-milter",          GST_ROLE_ANTIVIRUS },
+	{ "clamd",                  GST_ROLE_ANTIVIRUS },
 	{ "clvm",                   GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "cman",                   GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "courier",                GST_ROLE_MTA },
@@ -96,6 +100,7 @@ static ServiceRole services[] = {
 	{ "hplip",                  GST_ROLE_PRINTER_SERVICE },
 	{ "httpd",                  GST_ROLE_WEB_SERVER },
 	{ "inetd",                  GST_ROLE_NETWORK },
+	{ "iptables",               GST_ROLE_FIREWALL_MANAGEMENT },
 	{ "ipvsadm",                GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "irda",                   GST_ROLE_INFRARED_MANAGEMENT },
 	{ "irda-setup",             GST_ROLE_INFRARED_MANAGEMENT },
@@ -105,6 +110,7 @@ static ServiceRole services[] = {
 	{ "kdm",                    GST_ROLE_DISPLAY_MANAGER },
 	{ "keepalived",             GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "klogd",                  GST_ROLE_SYSTEM_LOGGER },
+	{ "landscape-client",       GST_ROLE_SYSTEM_MONITORING },
 	{ "lighttpd",               GST_ROLE_WEB_SERVER },
 	{ "lm-sensors",             GST_ROLE_HARDWARE_MONITORING },
 	{ "lpd",                    GST_ROLE_PRINTER_SERVICE },
@@ -115,14 +121,17 @@ static ServiceRole services[] = {
 	{ "mailscanner",            GST_ROLE_ANTIVIRUS },
 	{ "mdadm",                  GST_ROLE_RAID_MANAGEMENT },
 	{ "mdadm-raid",             GST_ROLE_RAID_MANAGEMENT },
+	{ "messagebus",             GST_ROLE_DBUS },
 	{ "metalog",                GST_ROLE_SYSTEM_LOGGER },
 	{ "mgetty-fax",             GST_ROLE_FAX_MANAGEMENT },
+	{ "mksd",                   GST_ROLE_ANTIVIRUS },
 	{ "muddleftpd",             GST_ROLE_FILE_SERVER_FTP },
 	{ "multipath-tools",        GST_ROLE_LVM_MANAGEMENT },
 	{ "mysql",                  GST_ROLE_DATABASE_SERVER },
 	{ "mysql-ndb",              GST_ROLE_DATABASE_SERVER },
 	{ "mysql-ndb-mgm",          GST_ROLE_DATABASE_SERVER },
 	{ "nagios",                 GST_ROLE_SECURITY_AUDITING },
+	{ "named",                  GST_ROLE_DNS },
 	{ "nbd-client",             GST_ROLE_DISK_CLIENT },
 	{ "nbd-server",             GST_ROLE_DISK_SERVER },
 	{ "nessusd",                GST_ROLE_SECURITY_AUDITING },
@@ -130,6 +139,7 @@ static ServiceRole services[] = {
 	{ "nfs",                    GST_ROLE_FILE_SERVER_NFS },
 	{ "nfs-kernel-server",      GST_ROLE_FILE_SERVER_NFS },
 	{ "nfs-user-server",        GST_ROLE_FILE_SERVER_NFS },
+	{ "nginx",                  GST_ROLE_WEB_SERVER },
 	{ "nis",                    GST_ROLE_NSS },
 	{ "ntp",                    GST_ROLE_NTP_SERVER },
 	{ "ntp-server",             GST_ROLE_NTP_SERVER },
@@ -156,11 +166,13 @@ static ServiceRole services[] = {
 	{ "pptpd",                  GST_ROLE_VPN_SERVER },
 	{ "proftpd",                GST_ROLE_FILE_SERVER_FTP },
 	{ "pure-ftpd",              GST_ROLE_FILE_SERVER_FTP },
+	{ "rc-inetd",               GST_ROLE_NETWORK },
 	{ "qmail",                  GST_ROLE_MTA },
 	{ "quagga",                 GST_ROLE_ROUTE_SERVER },
 	{ "quota",                  GST_ROLE_QUOTA_MANAGEMENT },
 	{ "racoon",                 GST_ROLE_IPSEC_KEY_EXCHANGE_SERVER },
 	{ "radvd",                  GST_ROLE_ROUTER_ADVERTISEMENT_SERVER },
+	{ "rdate",                  GST_ROLE_NTP_SERVER },
 	{ "rgmanager",              GST_ROLE_CLUSTER_MANAGEMENT },
 	{ "rsync",                  GST_ROLE_REMOTE_BACKUP },
 	{ "rsyncd",                 GST_ROLE_REMOTE_BACKUP },
@@ -172,7 +184,9 @@ static ServiceRole services[] = {
 	{ "sensord",                GST_ROLE_HARDWARE_MONITORING },
 	{ "shorewall",              GST_ROLE_FIREWALL_MANAGEMENT },
 	{ "slapd",                  GST_ROLE_LDAP_SERVER },
+	{ "slim",                   GST_ROLE_DISPLAY_MANAGER },
 	{ "smartmontools",          GST_ROLE_HARDWARE_MONITORING },
+	{ "smb",                    GST_ROLE_FILE_SERVER_SMB },
 	{ "snmpd",                  GST_ROLE_SNMP_SERVER },
 	{ "spamassassin",           GST_ROLE_SPAM_FILTER },
 	{ "squid",                  GST_ROLE_PROXY_CACHE },
@@ -180,8 +194,10 @@ static ServiceRole services[] = {
 	{ "sshd",                   GST_ROLE_SECURE_SHELL_SERVER },
 	{ "sysklogd",               GST_ROLE_SYSTEM_LOGGER },
 	{ "syslog",                 GST_ROLE_SYSTEM_LOGGER },
+	{ "syslog-ng",              GST_ROLE_SYSTEM_LOGGER },
 	{ "tftpd-hpa",              GST_ROLE_FILE_SERVER_TFTP },
 	{ "vcron",                  GST_ROLE_COMMAND_SCHEDULER },
+	{ "vixie-cron",             GST_ROLE_COMMAND_SCHEDULER },
 	{ "vmware-player",          GST_ROLE_VIRTUAL_MACHINE_MANAGEMENT },
 	{ "vsftpd",                 GST_ROLE_FILE_SERVER_FTP },
 	{ "wacom-tools",            GST_ROLE_GRAPHIC_TABLETS_MANAGEMENT },
@@ -193,6 +209,7 @@ static ServiceRole services[] = {
 	{ "xinetd",                 GST_ROLE_NETWORK },
 	{ "zmailer",                GST_ROLE_MTA },
 	{ "zope3",                  GST_ROLE_APPLICATION_SERVER },
+	{ "NetworkManager",         GST_ROLE_NETWORK },
 };
 
 static int
