@@ -48,6 +48,7 @@ struct _GstTool {
 	gchar *name;
 	gchar *title;
 	gchar *icon;
+	gboolean lock_button;
 
 	OobsSession *session;
 	GPtrArray   *objects;
@@ -88,6 +89,11 @@ void         gst_init                     (const gchar *app_name,
 					   int argc, char *argv [],
 					   GOptionEntry *entries);
 
+void         gst_init_tool                (const char   *app_name,
+                                           int           argc,
+                                           char         *argv [],
+                                           GOptionEntry *entries);
+
 void         gst_tool_update_gui          (GstTool *tool);
 void         gst_tool_update_config       (GstTool *tool);
 void         gst_tool_close               (GstTool *tool);
