@@ -237,6 +237,6 @@ gst_shares_tool_new (void)
 	return g_object_new (GST_TYPE_SHARES_TOOL,
 			     "name", "shares",
 			     "title", _("Shared Folders"),
-			     "icon", "gnome-fs-share",
+			     "icon", "folder-remote",
 			     NULL);
 }
