@@ -233,7 +233,7 @@ e_map_init (EMap *view)
 	priv = g_new0 (EMapPrivate, 1);
 	view->priv = priv;
 
-	load_map_background (view, MAP_DIR"/world_map-960.png");
+	load_map_background (view, PIXMAPS_DIR"/world_map-960.png");
 	priv->frozen = FALSE;
 	priv->smooth_zoom = TRUE;
 	priv->zoom_state = E_MAP_ZOOMED_OUT;
@@ -1274,7 +1274,9 @@ scroll_to (EMap *view, int x, int y)
 	int width, height;
 	int src_x, src_y;
 	int dest_x, dest_y;
+#if 0  /* see comment below */
 	GdkEvent *event;
+#endif
 
 	priv = view->priv;
 
@@ -1350,6 +1352,11 @@ scroll_to (EMap *view, int x, int y)
 
 	/* Process graphics exposures */
 
+	/* XXX gdk_event_get_graphics_expose() is deprecated now.
+	 *     The map widget seems to work fine without this logic
+	 *     (I think it was just an optimization) but leaving it
+	 *     intact in case I'm wrong and we need to rewrite it. */
+#if 0
 	while ((event = gdk_event_get_graphics_expose (window)) != NULL)
 	{
 		gtk_widget_event (GTK_WIDGET (view), event);
@@ -1362,6 +1369,7 @@ scroll_to (EMap *view, int x, int y)
 
 		gdk_event_free (event);
 	}
+#endif
 }
 
 
@@ -1777,8 +1785,8 @@ set_scroll_area (EMap *view)
 	if (priv->map_render_pixbuf)
 		priv->vadj->upper = gdk_pixbuf_get_height (priv->map_render_pixbuf);
 
-	gtk_signal_emit_by_name (GTK_OBJECT (priv->hadj), "changed");
-	gtk_signal_emit_by_name (GTK_OBJECT (priv->vadj), "changed");
+	g_signal_emit_by_name(G_OBJECT(priv->hadj), "changed");
+	g_signal_emit_by_name(G_OBJECT(priv->vadj), "changed");
 
 	priv->xofs = CLAMP (priv->xofs, 0, priv->hadj->upper - priv->hadj->page_size);
 	priv->yofs = CLAMP (priv->yofs, 0, priv->vadj->upper - priv->vadj->page_size);
