@@ -26,7 +26,9 @@
 #include <glib/gi18n.h>
 
 #include <string.h>
+#include <ctype.h>
 
+#include "group-members-table.h"
 #include "groups-table.h"
 #include "table.h"
 #include "callbacks.h"
@@ -162,6 +164,10 @@ group_settings_dialog_new (OobsGroup *group)
 	dialog = gst_dialog_get_widget (tool->main_dialog, "group_settings_dialog");
 	name = oobs_group_get_name (group);
 
+	/* Set this before setting the GID so that it's not rejected */
+	widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_gid");
+	gtk_spin_button_set_range (GTK_SPIN_BUTTON (widget), 0, G_MAXINT32);
+
 	if (!name) {
 		g_object_set_data (G_OBJECT (dialog), "is_new", GINT_TO_POINTER (TRUE));
 		gtk_window_set_title (GTK_WINDOW (dialog), _("New group"));
@@ -184,9 +190,6 @@ group_settings_dialog_new (OobsGroup *group)
 	gtk_entry_set_text (GTK_ENTRY (widget), (name) ? name : "");
 	gtk_widget_set_sensitive (widget, (name == NULL));
 
-	widget = gst_dialog_get_widget (tool->main_dialog, "group_settings_gid");
-	gtk_spin_button_set_range (GTK_SPIN_BUTTON (widget), 0, G_MAXINT32);
-
 	group_members_table_set_from_group (group);
 
 	return dialog;
@@ -215,7 +218,8 @@ is_group_root (OobsGroup *group)
 	return (strcmp (name, "root") == 0);
 }
 
-/* Get the OobsGroup corresponding to a name, or NULL if it does not exist */
+/* Get the OobsGroup corresponding to a name, or NULL if it does not exist.
+ * Don't forget to unref the group when valid. */
 OobsGroup *
 group_settings_get_group_from_name (const gchar *name)
 {
