@@ -26,9 +26,9 @@
 
 enum {
 	COL_GROUP_NAME,
-	COL_GROUP_GID,
-	COL_GROUP_POINTER,
-
+	COL_GROUP_ID,
+	COL_GROUP_OBJECT,
+	COL_GROUP_ITER,
 	COL_GROUP_LAST
 };
 
@@ -49,8 +49,15 @@ struct GroupTreeItem_
 	GroupTreeItem *children;
 };
 
+void    groups_table_clear              (void);
 void	create_groups_table		(void);
 void	populate_groups_table		(void);
 void	group_table_update_content	(void);
 
+void    groups_table_set_group          (OobsGroup    *group,
+                                         OobsListIter *list_iter,
+                                         GtkTreeIter  *iter);
+void    groups_table_add_group          (OobsGroup    *group,
+                                         OobsListIter *list_iter);
+
 #endif /* _GROUPS_TABLE_H */
