@@ -18,12 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
- * Authors: Carlos Garnacho Parro <garparr@teleline.es>
+ * Authors: Carlos Garnacho Parro <garparr@teleline.es>,
+ *          Milan Bouchet-Valat <nalimilan@club.fr>.
  */
 
 #include <config.h>
 #include "gst.h"
 #include <glib/gi18n.h>
+#include <pango/pango.h>
 
 #include "table.h"
 #include "users-table.h"
@@ -97,20 +99,9 @@ setup_shells_combo (GstUsersTool *tool)
 {
 	GtkWidget *combo;
 	GtkTreeModel *model;
-	GtkTreeIter iter;
-	GList *shells;
 
 	combo = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "user_settings_shell");
 	model = GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING));
-	shells = oobs_users_config_get_available_shells (OOBS_USERS_CONFIG (tool->users_config));
-
-	while (shells) {
-		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    0, shells->data,
-				    -1);
-		shells = shells->next;
-	}
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), model);
 	g_object_unref (model);
@@ -118,72 +109,92 @@ setup_shells_combo (GstUsersTool *tool)
 	gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
 }
 
-static void
-setup_profiles_combo (void)
-{
-	GtkWidget *combo = gst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu");
-	GtkTreeModel *model;
-	GtkCellRenderer *cell;
-
-	cell = gtk_cell_renderer_text_new();
-	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT (combo), cell, TRUE);
-	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT (combo), cell, "text", 0, NULL);
-
-	model = GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING));
-	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), model);
-	g_object_unref (model);
-}
-
 void
 table_populate_profiles (GstUsersTool *tool,
-			 GList        *names)
+                         GList *profiles)
 {
-	GtkWidget *combo;
-	GtkTreeModel *model;
-	GtkTreeIter iter;
+	GstUserProfile *profile;
+	GtkWidget *table;
+	GtkWidget *radio;
+	GtkWidget *label;
+	GHashTable *radios;
+	GHashTable *labels;
+	GHashTableIter iter;
+	gpointer value;
+	GList *l;
+	static int ncols, nrows; /* original size of the table */
+	PangoAttribute *attribute;
+	PangoAttrList *attributes;
+	int i;
 
-	combo = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "user_settings_profile_menu");
-	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
-	gtk_list_store_clear (GTK_LIST_STORE (model));
+	table = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "user_profile_table");
+	radios = g_object_get_data (G_OBJECT (table), "radio_buttons");
+	labels = g_object_get_data (G_OBJECT (table), "labels");
 
-	while (names) {
-		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, names->data, -1);
-		names = names->next;
+	/* create the hash table to hold references to radio buttons and their labels */
+	if (radios == NULL) {
+		/* keys are names owned by GstUserProfiles, values are pointers:
+		 * no need to free anything */
+		radios = g_hash_table_new (g_str_hash, g_str_equal);
+		labels = g_hash_table_new (g_str_hash, g_str_equal);
+		g_object_set_data (G_OBJECT (table), "radio_buttons", radios);
+		g_object_set_data (G_OBJECT (table), "labels", labels);
+		g_object_get (G_OBJECT (table), "n-rows", &nrows, "n-columns", &ncols, NULL);
 	}
-}
+	else {
+		/* free the radio buttons and labels if they were already here */
+		g_hash_table_iter_init (&iter, radios);
+		while (g_hash_table_iter_next (&iter, NULL, &value)) {
+			gtk_widget_destroy (GTK_WIDGET (value));
+		}
 
-void
-table_set_default_profile (GstUsersTool *tool)
-{
-	GtkWidget *combo;
-	GtkTreeModel *model;
-	GtkTreeIter iter;
-	GstUserProfile *default_profile;
-	gchar *profile;
-	gboolean valid;
+		g_hash_table_iter_init (&iter, labels);
+		while (g_hash_table_iter_next (&iter, NULL, &value)) {
+			gtk_widget_destroy (GTK_WIDGET (value));
+		}
 
-	default_profile = gst_user_profiles_get_default_profile (tool->profiles);
-	combo = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "user_settings_profile_menu");
-	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
-	valid = gtk_tree_model_get_iter_first (model, &iter);
-
-	while (valid) {
-		gtk_tree_model_get (model, &iter, 0, &profile, -1);
-
-		if (default_profile &&
-		    strcmp (profile, default_profile->name) == 0) {
-			g_signal_handlers_block_by_func (G_OBJECT (combo), on_user_settings_profile_changed, GST_TOOL (tool)->main_dialog);
-			gtk_combo_box_set_active_iter (GTK_COMBO_BOX (combo), &iter);
-			g_signal_handlers_unblock_by_func (G_OBJECT (combo), on_user_settings_profile_changed, GST_TOOL (tool)->main_dialog);
-			valid = FALSE;
-		} else
-			valid = gtk_tree_model_iter_next (model, &iter);
-
-		g_free (profile);
+		g_hash_table_remove_all (radios);
+		g_hash_table_remove_all (labels);
 	}
 
-	user_settings_apply_profile (tool, default_profile);
+	/* increase table's size based on it's "empty" size
+	 * we leave an empty line after a radio and its decription label */
+	gtk_table_resize (GTK_TABLE (table), g_list_length (profiles) * 3 + nrows, ncols);
+
+	radio = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "user_profile_custom");
+	label = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "user_profile_custom_label");
+
+	attributes = pango_attr_list_new ();
+	attribute = pango_attr_size_new (9 * PANGO_SCALE);
+	pango_attr_list_insert (attributes, attribute);
+	attribute = pango_attr_style_new (PANGO_STYLE_ITALIC);
+	pango_attr_list_insert (attributes, attribute);
+	gtk_label_set_attributes (GTK_LABEL (label), attributes);
+
+	i = 1; /* empty line after "Custom" radio and label */
+	for (l = profiles; l; l = l->next) {
+		profile = (GstUserProfile *) l->data;
+		radio = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (radio),
+		                                                     profile->name);
+		label = gtk_label_new (profile->description);
+		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+		gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+		gtk_misc_set_padding (GTK_MISC (label), 16, 0);
+		gtk_label_set_attributes (GTK_LABEL (label), attributes);
+
+		gtk_table_attach_defaults (GTK_TABLE (table),
+		                           radio, 0, ncols,
+		                           nrows + i, nrows + i + 1);
+		gtk_table_attach_defaults (GTK_TABLE (table),
+		                           label, 1, ncols,
+		                           nrows + i + 1, nrows + i + 2);
+		gtk_widget_show (radio);
+		gtk_widget_show (label);
+
+		g_hash_table_replace (radios, profile->name, radio);
+		g_hash_table_replace (labels, profile->name, label);
+		i += 3;
+	}
 }
 
 void
@@ -195,7 +206,6 @@ create_tables (GstUsersTool *tool)
 	create_group_members_table ();
 
 	/* not strictly tables, but uses a model */
-	setup_profiles_combo ();
 	setup_groups_combo ();
 	setup_shells_combo (tool);
 }
