@@ -23,14 +23,16 @@
 #include <glib/gi18n.h>
 #include "callbacks.h"
 #include "user-profiles.h"
+#include "users-table.h"
+#include "groups-table.h"
+#include "privileges-table.h"
+#include "table.h"
 #include "users-tool.h"
 #include "gst.h"
 
 static void  gst_users_tool_class_init     (GstUsersToolClass *class);
 static void  gst_users_tool_init           (GstUsersTool      *tool);
 static void  gst_users_tool_finalize       (GObject           *object);
-
-static void  gst_users_tool_update_gui     (GstTool *tool);
 static void  gst_users_tool_update_config  (GstTool *tool);
 
 static GObject* gst_users_tool_constructor (GType                  type,
@@ -107,9 +109,6 @@ gst_users_tool_constructor (GType                  type,
 	gst_conf_add_notify (GST_TOOL (tool), "showall",
 			     on_showall_changed, tool);
 
-	g_signal_connect (G_OBJECT (tool->main_dialog), "unlocked",
-			  G_CALLBACK (on_unlocked), NULL);
-
 	return object;
 }
 
@@ -145,6 +144,8 @@ update_users (GstUsersTool *tool)
 		g_object_unref (user);
 		valid = oobs_list_iter_next (list, &iter);
 	}
+
+	users_table_select_first ();
 }
 
 static void
@@ -176,19 +177,75 @@ update_groups (GstUsersTool *tool)
 static void
 update_profiles (GstUsersTool *tool)
 {
-	GList *names = NULL;
+	GList *list, *l;
+	GtkWidget *label1, *label2, *button;
+	GstUserProfile *profile;
+	int max_len, len;
 
-	names = gst_user_profiles_get_names (tool->profiles);
-	table_populate_profiles (tool, names);
-	g_list_free (names);
+	list = gst_user_profiles_get_list (tool->profiles);
+	table_populate_profiles (tool, list);
+
+	/* Hide profiles line in main dialog if only one profile is available */
+	label1 = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog,
+	                                "user_settings_profile");
+	label2 = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog,
+	                                "user_settings_profile_label");
+	button = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog,
+	                                "edit_user_profile_button");
+
+	if (g_list_length (list) > 1) {
+		gtk_widget_show (label1);
+		gtk_widget_show (label2);
+		gtk_widget_show (button);
+	}
+	else {
+		gtk_widget_hide (label1);
+		gtk_widget_hide (label2);
+		gtk_widget_hide (button);
+		return;
+	}
+
+	/* use the length of the longest profile name to avoid resizing
+	 * the label and moving widgets around */
+	max_len = 0;
+	for (l = list; l; l = l->next) {
+		profile = l->data;
+		len = g_utf8_strlen (profile->name, -1);
+		if (len > max_len)
+			max_len = len;
+	}
+
+	gtk_label_set_width_chars (GTK_LABEL (label1), max_len);
 }
 
 static void
+update_shells (GstUsersTool *tool)
+{
+	GtkWidget *combo;
+	GtkTreeModel *model;
+	GList *shells;
+	GtkTreeIter iter;
+
+	combo = gst_dialog_get_widget (GST_TOOL (tool)->main_dialog, "user_settings_shell");
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (combo));
+	shells = oobs_users_config_get_available_shells (OOBS_USERS_CONFIG (tool->users_config));
+
+	while (shells) {
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+				    0, shells->data,
+				    -1);
+		shells = shells->next;
+	}
+}
+
+void
 gst_users_tool_update_gui (GstTool *tool)
 {
 	update_users (GST_USERS_TOOL (tool));
 	update_groups (GST_USERS_TOOL (tool));
 	update_profiles (GST_USERS_TOOL (tool));
+	update_shells (GST_USERS_TOOL (tool));
 }
 
 static void
@@ -215,5 +272,6 @@ gst_users_tool_new (void)
 			     "name", "users",
 			     "title", _("Users Settings"),
 			     "icon", "config-users",
+	                     "lock-button", FALSE,
 			     NULL);
 }
